PSD support for Pymaging
========================

This module provides basic PSD support for Pymaging_.
The license is MIT.

Installation
------------

::

    pip install pymaging-psd

This module requires `psd-tools`_, packbits_ and distribute_.

.. _Pymaging: https://github.com/ojii/pymaging
.. _psd-tools: http://pypi.python.org/pypi/psd-tools/
.. _packbits: http://pypi.python.org/pypi/packbits/
.. _distribute: http://pypi.python.org/pypi/distribute

Contributing
------------

Development happens at github and bitbucket:

* https://github.com/kmike/pymaging-psd
* https://bitbucket.org/kmike/pymaging-psd

The main issue tracker is at github: https://github.com/kmike/pymaging-psd/issues

Feel free to submit ideas, bugs, pull requests (git or hg) or regular patches.
